Boxplot module
mod_boxplot.Rdmod_boxplot is a Shiny module prepared to display data with boxplot charts with different levels of grouping.
It also includes a set of listings with information about the population, distribution and statistical comparisons.
Usage
mod_boxplot(
module_id,
bm_dataset_name,
group_dataset_name,
receiver_id = NULL,
cat_var = "PARCAT",
par_var = "PARAM",
value_vars = "AVAL",
x_axis_vars = NULL,
visit_var = NULL,
anlfl_vars = NULL,
subjid_var = "SUBJID",
quantile_type = 7L,
default_cat = NULL,
default_par = NULL,
default_x_axis_var = NULL,
default_x_axis_vals = NULL,
default_visit = NULL,
default_value = NULL,
default_main_group = NULL,
default_sub_group = NULL,
default_page_group = NULL,
server_wrapper_func = function(x) list(subj_id = x)
)Arguments
- module_id
[character(1)]Module Shiny id
- bm_dataset_name, group_dataset_name
[character(1)]Name of the dataset
- receiver_id
[character(1)]Shiny ID of the module receiving the selected subject ID in the data listing. This ID must be present in the app or be NULL.
- cat_var, par_var
[character(1)]Columns from
bm_datasetthat correspond to the parameter category and parameter- value_vars
[character(n)]Columns from
bm_datasetthat correspond to values of the parameters- x_axis_vars
[character(n)]Columns from
bm_datasetthat correspond to x-axis variables- visit_var
Deprecated. Use
x_axis_vars.- anlfl_vars
[character(n)]Columns from
bm_datasetthat correspond to analysis flags- subjid_var
[character(1)]Column corresponding to subject ID
- quantile_type
[integer(1)]Quantile algorithm type passed to
quantile(an integer between 1 and 9, default 7).- default_cat, default_par, default_x_axis_var, default_value, default_main_group, default_sub_group, default_page_group
[character(1)|NULL]Default values for the selectors
- default_x_axis_vals
[character(n)|NULL]Default values for the x-axis variable
- default_visit
Deprecated. Use
default_x_axis_vals.- server_wrapper_func
[function()]A function that will be applied to the server returned value. Its default value will work for the current cases.